@@ -8,6 +8,8 @@
 ( cd opt/kde/lib ; ln -sf libqtc.so.1.0.0 libqtc.so.1 )
 ( cd opt/kde/lib ; rm -rf libqtc.so )
 ( cd opt/kde/lib ; ln -sf libqtc.so.1.0.0 libqtc.so )
+( cd opt/kde/lib ; rm -rf libkdec.so.1 )
+( cd opt/kde/lib ; ln -sf libkdec.so.1.0.0 libkdec.so.1 )
 ( cd opt/kde/lib ; rm -rf libkdexparts.so.1 )
 ( cd opt/kde/lib ; ln -sf libkdexparts.so.1.0.0 libkdexparts.so.1 )
 ( cd opt/kde/lib ; rm -rf libkjsembed.so )
@@ -20,6 +22,8 @@
 ( cd opt/kde/lib ; ln -sf libgtkxparts.so.0.0.0 libgtkxparts.so )
 ( cd opt/kde/lib ; rm -rf libxp_notepadpart.so.0 )
 ( cd opt/kde/lib ; ln -sf libxp_notepadpart.so.0.0.0 libxp_notepadpart.so.0 )
+( cd opt/kde/lib ; rm -rf libkdec.so )
+( cd opt/kde/lib ; ln -sf libkdec.so.1.0.0 libkdec.so )
 ( cd opt/kde/lib ; rm -rf libkdexparts.so )
 ( cd opt/kde/lib ; ln -sf libkdexparts.so.1.0.0 libkdexparts.so )
 ( cd opt/kde/lib ; rm -rf libgtkxparts.so.0 )
